import moment from 'moment';

export const GetFormatter = {
    INPUT: (val) => {
        const obj = Array.isArray(val) && val.length > 0 ? val[0] : {};
        return obj.value;
    },
    SEARCH: (val) => {
        if (!Array.isArray(val)) return void 0;
        return val
            .map((item) => ({ value: item.value, label: item.text }))
            .filter((item) => item.value || item.value === 0);
    },
    TEXTAREA: (val) => {
        const obj = Array.isArray(val) && val.length > 0 ? val[0] : {};
        return obj.value;
    },
    UPLOAD: (val) => {
        if (!Array.isArray(val)) return void 0;
        return val.map((item) => {
            let size = 0;
            let text = item.text.replace(/\((\d+)\)$/, (s0, s1, s2) => {
                size = s1;
                return '';
            });
            return { value: item.value, name: text, size };
        });
    },
    CHECKBOX: (val) => {
        const obj = Array.isArray(val) && val.length > 0 ? val[0] : {};
        return obj.value;
    },
    SELECT: (val) => {
        // 处理成[{}]结构
        const obj = val[0] || {};
        return { key: obj.value, label: obj.text };
    },
    MULTIPLE_SELECT: (val) => {
        // 处理成[{}]结构
        const obj = val[0] || {};
        return { key: obj.value, label: obj.text };
    },
    RATE: (val) => {
        const obj = Array.isArray(val) && val.length > 0 ? val[0] : {};
        return obj.value || 0;
    },
    NUMBER: (val) => {
        const obj = Array.isArray(val) && val.length > 0 ? val[0] : {};
        return obj.value;
    },
    PERCENTAGE: (val) => {
        const obj = Array.isArray(val) && val.length > 0 ? val[0] : {};
        return obj.value;
    },
    DATE: (val) => {
        const obj = Array.isArray(val) && val.length > 0 ? val[0] : {};
        return obj.value ? moment(obj.value) : void 0;
    },
    LINK: (val) => {
        const obj = Array.isArray(val) && val.length > 0 ? val[0] : {};
        return obj.value;
    },
    MULTIPLE_SEARCH: (val) => {
        if (!Array.isArray(val)) return void 0;
        return val
            .map((item) => ({ value: item.value, label: item.text }))
            .filter((item) => item.value || item.value === 0);
    },
    TREE_SELECT: (val) => {
        if (!Array.isArray(val)) return void 0;
        return val.map((item) => ({ value: item.value, label: item.text }));
    },
    TEXT_SELECT: (val) => {
        if (!Array.isArray(val)) return void 0;
        return val
            .map((item) => ({
                value: item.value,
                label: item.text,
            }))
            .filter((item) => item.value || item.value === 0 || item.label);
    },
};
